@@ -15,8 +15,9 @@ from smtplib import SMTP, SMTPException
 from google.cloud.bigquery import Client, LoadJobConfig, DatasetReference
 from google.cloud.bigquery import SchemaField as sf
 from google.oauth2 import service_account
-from functions import left
-from functions import right
+
+from CsPy_Uploading.functions import left
+from CsPy_Uploading.functions import right
 
 
 # TODO: Maybe add data cleaning within the download job
@@ -185,7 +186,7 @@ class BaseJob:
             &&&&&&&@               &&&&&&&%           &&&&&&&.         &&&&&&&&&&&&&&&&&&&&&&&*    
             &&&&&&&@               &&&&&&&%           &&&&&&&.            &&&&&&&&&&&&&&&&@&.       
      
-    CsPy Uploading Python Package Version: 1.0.0""")
+    CsPy Uploading Python Package Version: 1.0.1""")
             print('=' * 99)
 
     def insert_line(self):
